﻿using System;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                                += Form_Load;
            this.treeList.TreeListMenuItemClick += treeList_TreeListMenuItemClick;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.treeList.RowHeight                              = 25;
            this.treeList.OptionsView.AutoWidth                  = false;
            this.treeList.OptionsBehavior.ReadOnly               = true;
            this.treeList.OptionsBehavior.PopulateServiceColumns = true;
            this.treeList.KeyFieldName                           = "ID";
            this.treeList.ParentFieldName                        = "RegionID";

            this.treeList.DataSource = SalesData.GetSalesDataList();

            this.treeList.Columns[this.treeList.KeyFieldName   ].Visible = false;
            this.treeList.Columns[this.treeList.ParentFieldName].Visible = false;

            this.treeList.BestFitColumns();

            this.treeList.ExpandAll();
        }

        #endregion
        #region 트리 리스트 메뉴 항목 클릭시 처리하기 - treeList_TreeListMenuItemClick(sender, e)

        /// <summary>
        /// 트리 리스트 메뉴 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_TreeListMenuItemClick(object sender, TreeListMenuItemClickEventArgs e)
        {
            if(e.IsFooter)
            {
                return;
            }

            TreeList treeList = sender as TreeList;

            if(e.MenuItem.Caption == "Sort Ascending" || e.MenuItem.Caption == "Sort Descending")
            {
                treeList.ClearSorting();

                if(e.MenuItem.Caption == "Sort Ascending") 
                {
                    e.Column.SortOrder = SortOrder.Descending;
                }
                else 
                {
                    e.Column.SortOrder = SortOrder.Ascending;
                }

                e.Handled = true;
            }
        }

        #endregion
    }
}